# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["PortingOrderDocumentsParam"]


class PortingOrderDocumentsParam(TypedDict, total=False):
    invoice: str
    """Returned ID of the submitted Invoice via the Documents endpoint"""

    loa: str
    """Returned ID of the submitted LOA via the Documents endpoint"""
