# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types import DocumentLinkListResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDocumentLinks:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        document_link = client.document_links.list()
        assert_matches_type(DocumentLinkListResponse, document_link, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        document_link = client.document_links.list(
            filter={
                "linked_record_type": "porting_order",
                "linked_resource_id": "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
            },
            page={
                "number": 1,
                "size": 1,
            },
        )
        assert_matches_type(DocumentLinkListResponse, document_link, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.document_links.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document_link = response.parse()
        assert_matches_type(DocumentLinkListResponse, document_link, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.document_links.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document_link = response.parse()
            assert_matches_type(DocumentLinkListResponse, document_link, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncDocumentLinks:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        document_link = await async_client.document_links.list()
        assert_matches_type(DocumentLinkListResponse, document_link, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        document_link = await async_client.document_links.list(
            filter={
                "linked_record_type": "porting_order",
                "linked_resource_id": "6a09cdc3-8948-47f0-aa62-74ac943d6c58",
            },
            page={
                "number": 1,
                "size": 1,
            },
        )
        assert_matches_type(DocumentLinkListResponse, document_link, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.document_links.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document_link = await response.parse()
        assert_matches_type(DocumentLinkListResponse, document_link, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.document_links.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document_link = await response.parse()
            assert_matches_type(DocumentLinkListResponse, document_link, path=["response"])

        assert cast(Any, response.is_closed) is True
