# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union
from typing_extensions import TypeAlias

__all__ = ["EnumRetrieveResponse"]

EnumRetrieveResponse: TypeAlias = Union[List[Union[str, object]], object, object]
